@@ -1,17 +1,21 @@
 /*
  * SPDX-FileCopyrightText: 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
- * 
+ *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #pragma once
 
 #include <QObject>
+#include <QPointer>
 
 class PageDataObject;
 class QQuickItem;
 
-namespace KSysGuard { class SensorFaceController; }
+namespace KSysGuard
+{
+class SensorFaceController;
+}
 
 class FaceLoader : public QObject
 {
@@ -21,6 +25,7 @@ class FaceLoader : public QObject
 
 public:
     FaceLoader(QObject *parent = nullptr);
+    ~FaceLoader() override;
 
     PageDataObject *dataObject() const;
     void setDataObject(PageDataObject *newDataObject);
@@ -32,7 +37,7 @@ public:
     void reset();
 
 private:
-    PageDataObject *m_dataObject = nullptr;
+    QPointer<PageDataObject> m_dataObject = nullptr;
     KSysGuard::SensorFaceController *m_faceController = nullptr;
     KSysGuard::SensorFaceController *m_oldController = nullptr;
 
